==> dhall-1.42.3-38-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-9ADZYYEQIffCT3aQ2XvvFm
key:                  dhall-1.42.3-9ADZYYEQIffCT3aQ2XvvFm
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  e6ede6d02be9ba74bd15d69c3918dbd7
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-9ADZYYEQIffCT3aQ2XvvFm
depends:
    Diff-0.5-HhQaTNERhJmIrCyukvTeRE
    aeson-2.2.0.0-A8FqDK4tVym6hhqwC7qXFC
    aeson-pretty-0.8.10-6HP8hq3xeCjAEAaTtCFcSi
    ansi-terminal-1.0.2-5XGQCBITBQK54h4mZtEY0l
    atomic-write-0.2.1.1-L0JPxZ5cFpHC0GyHuH29kC base-4.18.2.1
    base16-bytestring-1.0.2.0-IBSXo3fNQsx2cpIyb3dUEY
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8vz9c08oERN6HaPlnW3IdE
    cborg-0.2.10.0-KhzGivewifn5pwYk8XRmvJ
    cborg-json-0.2.6.0-5RPV4Sdys4a6gXB82i4b3u containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    cryptohash-sha256-0.11.102.1-BZqp0izleNr6mS9yEuCRuc
    data-fix-0.3.4-37TXZE518z87bYJzlbyPiI deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-9hRC76jO87lEtB307S4pUs exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-4QCzYOXOYrh36480cTiYfP
    hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM haskeline-0.8.2.1
    http-client-0.7.19-5kCWQrqBeyJH4fxMxrytAc
    http-client-tls-0.3.6.4-4YjTfjzKPdw6FEP2jTEQj6
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-EJ90AsoHAMdCjQYvJMoIz4
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-EsX0tHV5l49AhOs5hDRDmc
    optparse-applicative-0.18.1.0-LPpsyWWBTB8DZOwBIqw3J0
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    parsers-0.12.12-3ctdS7BplAaRKS9RF5B8
    pretty-simple-4.1.4.0-JrPpxJXbArkDpLMms4WfTy
    prettyprinter-1.7.1-1A9qDzGwN5aD62WFF8DTGH
    prettyprinter-ansi-terminal-1.1.3-G5Cp0eNbSihDBZ7L9crRUI
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.0-JLcC8H5zZSyDPbVdOVmQEk
    serialise-0.2.6.1-6jfUiJXvmgFJ2duuasvk4r template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-8zmOuB2F84FPkbeHMktko
    text-short-0.1.6-CRqxlTSDqjNLpmYJDg2unF
    th-lift-instances-0.1.20-9vxKZwmnoda24dn6m63lzz time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-7Zyia4XRlOQIIQMyLxI1QD
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-1.42.3-39-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-1X59rQVrOKBClnCvPZPB8X
key:                  dhall-1.42.3-1X59rQVrOKBClnCvPZPB8X
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  aa51ad4e3dbcef98642daceca4a8ca37
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-1X59rQVrOKBClnCvPZPB8X
depends:
    Diff-0.5-9iFzYwbbznxCTrvC5fevGO
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    aeson-pretty-0.8.10-LSDchJgtnQ46sIK4bUu3co
    ansi-terminal-1.1-6H4MdlQ9LS5JB7dL181Y6t
    atomic-write-0.2.1.1-AsMO6HIm4atHCpp0LeNZ57 base-4.18.2.1
    base16-bytestring-1.0.2.0-4dU46p0HYXn6d3pnzwPlcc
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH
    cborg-0.2.10.0-21J6rLuks3u5ipDJSMHlso
    cborg-json-0.2.6.0-3PhfZP2D6Ou2aNhE6Zpsyr containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    cryptohash-sha256-0.11.102.1-BO36oUcGTLo3lAT0W1U2yt
    data-fix-0.3.4-BhpYQHhkqElEweHZHTCns2 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-L22t4kXU5q48Oo9K8geQIY exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-6LWqLfuEWfg75JYwnPALJU
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ haskeline-0.8.2.1
    http-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
    http-client-tls-0.3.6.4-LhFztqm7Yl955SnS7vNn0b
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-J7oRvDmmxLP8uuOmkK9aRM
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    optparse-applicative-0.18.1.0-9I3qDpNxi1rBTnWffPMXX3
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    parsers-0.12.12-E8V9WMg1iAu6QWQxft6n1O
    pretty-simple-4.1.4.0-AZ3GeM8HFLs4S8Llb2Kcw1
    prettyprinter-1.7.1-4PNEjQDcFkU8z4wKR8XxHs
    prettyprinter-ansi-terminal-1.1.3-16T9vhA2HoNHCC5fXPVq0T
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.0-CFYO4vxJ7Tde72prrjPHU
    serialise-0.2.6.1-BBVO2jFBuFy4qYd4rty9PR template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-4m8YIAIa0H2LFt7c7vo3FX
    text-short-0.1.6-4mdoyia35seAz3p4F6lL4y
    th-lift-instances-0.1.20-Ej9sJgLZWdHHLklsPTxbOD time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-DqDzbwuaouv1yXLtKQLq3q
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
